@@ -3,13 +3,17 @@ use strict;
 use Future;
 use AnyEvent::HTTP ();
 use AnyEvent::Future 'as_future_cb';
+BEGIN {
+    # Versions before that didn't have as_future_cb
+    AnyEvent::Future->VERSION(0.02)
+}
 use Moo 2; # or Moo::Lax if you can't have Moo v2
 use Filter::signatures;
 no warnings 'experimental::signatures';
 use feature 'signatures';
 
 use vars qw($VERSION);
-$VERSION = '0.05';
+$VERSION = '0.06';
 
 =head1 NAME
 
@@ -27,6 +31,7 @@ sub future_from_result {
     if( $headers->{Status} =~ /^2../ ) {
         return Future->done($body, $headers);
     } else {
+        $body ||= $headers->{Reason}; # just in case we didn't get a body at all
         return Future->fail($body, $headers);
     }
 }
